{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for TLA+.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/tlaplus.xml and 'make bootstrap'.
module Skylighting.Syntax.Tlaplus (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for TLA+.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTLA+\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vtlaplus.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aTlaplus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bkeywords\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKASSUME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nASSUMPTION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQAXIOM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCASE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKCHOOSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCONSTANT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCONSTANTS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKDOMAIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTELSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aENABLED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKEXCEPT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aEXTENDS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bINSTANCE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLOCAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKMODULE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQOTHER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSUBSET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTHEN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aTHEOREM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tUNCHANGED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQUNION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVARIABLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVARIABLES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTWITH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\toperators\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX/\\\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\\/\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX=>\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX<=>\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\\E\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\\A\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\\in\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\notin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\subset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\\subseteq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\supset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\\supseteq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\union\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\intersect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\\setminus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEMultiLineComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEMultiLineComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTLA+\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\SOH*)\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DLE\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKAlerts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTLA+\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKASSUME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nASSUMPTION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQAXIOM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCASE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKCHOOSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCONSTANT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCONSTANTS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKDOMAIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTELSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aENABLED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKEXCEPT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aEXTENDS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bINSTANCE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLOCAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKMODULE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQOTHER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSUBSET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTHEN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aTHEOREM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tUNCHANGED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQUNION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVARIABLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVARIABLES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTWITH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX/\\\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX<=>\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX=>\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\\/\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\\A\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\\E\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\\in\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\intersect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\notin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\\setminus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\subset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\\subseteq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\supset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\\supseteq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\union\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH~\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTLA+\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\SOH\\*\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTLA+\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1SingleLineComment\SOH(*\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTLA+\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEMultiLineComment\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1SingleLineComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1SingleLineComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTLA+\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKAlerts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTLA+\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\"\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNYounes (dev@younes.io)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.tla\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal"
